@@ -24,13 +24,13 @@ def path_from_uri(uri):
         _, path = uri.split("file:///", 1)
     else:
         _, path = uri.split("file://", 1)
-    return unquote(path)
+    return os.path.normpath(unquote(path))
 
 
 def path_to_uri(path):
     # Convert path to file uri (add html like head part)
     if os.name == "nt":
-        return "file:///" + quote(path)
+        return "file:///" + quote(path.replace('\\', '/'))
     else:
         return "file://" + quote(path)
 
